/* src/bazaar.p/bz-flathub-curated-selection.h
 *
 * Copyright 2026 AUTOGEN
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <glib-object.h>
#include "bz-application-map-factory.h"

G_BEGIN_DECLS



#define BZ_TYPE_FLATHUB_CURATED_SELECTION (bz_flathub_curated_selection_get_type ())
G_DECLARE_FINAL_TYPE (BzFlathubCuratedSelection, bz_flathub_curated_selection, BZ, FLATHUB_CURATED_SELECTION, GObject)

BzFlathubCuratedSelection *
bz_flathub_curated_selection_new (void);

const char *
bz_flathub_curated_selection_get_theme_key (BzFlathubCuratedSelection *self);

const char *
bz_flathub_curated_selection_get_slot (BzFlathubCuratedSelection *self);

GtkStringList *
bz_flathub_curated_selection_get_apps (BzFlathubCuratedSelection *self);

BzApplicationMapFactory *
bz_flathub_curated_selection_get_map_factory (BzFlathubCuratedSelection *self);

void
bz_flathub_curated_selection_set_theme_key (BzFlathubCuratedSelection *self,
    const char *theme_key);

void
bz_flathub_curated_selection_set_slot (BzFlathubCuratedSelection *self,
    const char *slot);

void
bz_flathub_curated_selection_set_apps (BzFlathubCuratedSelection *self,
    GtkStringList *apps);

void
bz_flathub_curated_selection_set_map_factory (BzFlathubCuratedSelection *self,
    BzApplicationMapFactory *map_factory);

void
bz_flathub_curated_selection_set_theme_key_take (BzFlathubCuratedSelection *self,
    char *theme_key);

#define bz_flathub_curated_selection_set_theme_key_take_printf(self, ...) bz_flathub_curated_selection_set_theme_key_take (self, g_strdup_printf (__VA_ARGS__))

void
bz_flathub_curated_selection_set_slot_take (BzFlathubCuratedSelection *self,
    char *slot);

#define bz_flathub_curated_selection_set_slot_take_printf(self, ...) bz_flathub_curated_selection_set_slot_take (self, g_strdup_printf (__VA_ARGS__))

G_END_DECLS

/* End of src/bazaar.p/bz-flathub-curated-selection.h */
